==> ZenTaoPMS.max2.0.rc1.php5.3_5.6.zip: zentaopms/module/upgrade/ext/config/zentaomax.php <==
<?php
$config->maxVersion = array();
$config->maxVersion['max2_0_rc1'] = '15_0_rc3';

$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello2.start.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test2.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/index.html';
$config->delete['20.0.beta3'][] = 'module/action/ext/model/hook/create.xuanxuan.php';

$config->delete['2.0.rc1'][] = 'module/bug/ext/model/zentaomax.php';
$config->delete['2.0.rc1'][] = 'module/doc/ext/view/browse.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/action/ext/model/class/search.class.php';
$config->delete['2.0.rc1'][] = 'module/action/ext/model/search.php';
$config->delete['2.0.rc1'][] = 'module/product/ext/model/web.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/calendar.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/effort.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/gantt.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/view.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/taskeffort.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/task.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/task.excel.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/requirement.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/relation.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/managemembers.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/maintainrelation.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/kanban.word.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/gantt.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/finish.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.gantt.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.calendar.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effortcalendar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effort.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effort.calendar.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/edit.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/calendar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/ajaxkanbansetting.flow.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/search/ext/model/search.php';
$config->delete['2.0.rc1'][] = 'module/story/ext/model/class/bizext.class.php';
$config->delete['2.0.rc1'][] = 'module/story/ext/model/bizext.php';
$config->delete['2.0.rc1'][] = 'module/dept/ext/model/getlistbytype.php';
$config->delete['2.0.rc1'][] = 'module/block/ext/lang/zh-cn/cmmi.php';

==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/upgrade/ext/config/zentaomax.php <==
<?php
$config->maxVersion = array();
$config->maxVersion['max2_0_rc1'] = '15_0_rc3';
$config->maxVersion['max2_0']     = '15_0';
$config->maxVersion['max2_1']     = '15_3';
$config->maxVersion['max2_2']     = '15_5';

$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello2.start.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test2.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/index.html';
$config->delete['20.0.beta3'][] = 'module/action/ext/model/hook/create.xuanxuan.php';

$config->delete['2.0.rc1'][] = 'module/bug/ext/model/zentaomax.php';
$config->delete['2.0.rc1'][] = 'module/doc/ext/view/browse.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/action/ext/model/class/search.class.php';
$config->delete['2.0.rc1'][] = 'module/action/ext/model/search.php';
$config->delete['2.0.rc1'][] = 'module/product/ext/model/web.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/calendar.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/effort.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/model/gantt.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/view.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/taskeffort.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/task.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/task.excel.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/requirement.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/relation.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/managemembers.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/maintainrelation.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/kanban.word.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/gantt.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/finish.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.gantt.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/featurebar.calendar.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effortcalendar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effort.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/effort.calendar.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/edit.cmmi.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/calendar.html.php';
$config->delete['2.0.rc1'][] = 'module/project/ext/view/ajaxkanbansetting.flow.html.hook.php';
$config->delete['2.0.rc1'][] = 'module/search/ext/model/search.php';
$config->delete['2.0.rc1'][] = 'module/story/ext/model/class/bizext.class.php';
$config->delete['2.0.rc1'][] = 'module/story/ext/model/bizext.php';
$config->delete['2.0.rc1'][] = 'module/dept/ext/model/getlistbytype.php';
$config->delete['2.0.rc1'][] = 'module/block/ext/lang/zh-cn/cmmi.php';
$config->delete['2.0.rc1'][] = 'module/group/ext/js/managepriv/cmmi.js';
$config->delete['2.0'][]     = 'module/group/ext/lang/zh-cn/zzcmmi.php';
$config->delete['2.0'][]     = 'module/group/ext/lang/en/zzcmmi.php';
$config->delete['2.0'][]     = 'module/project/ext/lang/zh-cn/cmmi.php';
